==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/SporetrapModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.world.entity.Sporetrap;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class SporetrapModel<T extends Sporetrap> extends class_583<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "sporetrap_model"), "main");
	private final class_630 base;
	private final class_630 innerLeaf1;
	private final class_630 innerLeaf2;
	private final class_630 innerLeaf3;
	private final class_630 innerLeaf4;
	private final class_630 stem;
	private final class_630 mouthTop;
	private final class_630 mouthBottom;

	public SporetrapModel(class_630 root) {
		this.base = root.method_32086("base");
		this.innerLeaf1 = root.method_32086("innerLeaf1");
		this.innerLeaf2 = root.method_32086("innerLeaf2");
		this.innerLeaf3 = root.method_32086("innerLeaf3");
		this.innerLeaf4 = root.method_32086("innerLeaf4");
		this.stem = root.method_32086("stem");
		this.mouthTop = root.method_32086("mouthTop");
		this.mouthBottom = root.method_32086("mouthBottom");
	}

	public void setupAnim(T pEntity, float pLimbSwing, float pLimbSwingAmount, float pAgeInTicks, float pNetHeadYaw, float pHeadPitch) {
		float f1 = class_3532.method_15362(pLimbSwing * 1.4F) * 0.8F * pLimbSwingAmount;
		float f2 = class_3532.method_15362(pLimbSwing * 1.4F + class_3532.field_29844 * 0.25F) * 0.8F * pLimbSwingAmount;
		float f3 = class_3532.method_15362(pLimbSwing * 1.4F + class_3532.field_29844 * 0.5F) * 0.8F * pLimbSwingAmount;
		float f4 = class_3532.method_15362(pLimbSwing * 1.4F + class_3532.field_29844 * 0.75F) * 0.8F * pLimbSwingAmount;
		float f5 = class_3532.method_15362(pLimbSwing * 1.4F + class_3532.field_29844) * 0.8F * pLimbSwingAmount;
		this.mouthTop.field_3654 = -2.8F;
		this.mouthBottom.field_3654 = 2.8F;
		this.mouthTop.field_3654 += f1;
		this.mouthBottom.field_3654 += f5;
		this.innerLeaf1.field_3654 = 1F;
		this.innerLeaf2.field_3654 = 1F;
		this.innerLeaf3.field_3674 = 1F;
		this.innerLeaf4.field_3674 = 1F;
//		this.innerLeaf1.xRot += f1;
//		this.innerLeaf2.xRot += f1;
//		this.innerLeaf3.zRot += f1;
//		this.innerLeaf4.zRot += f1;
	}

	public void method_2828(class_4587 poseStack, class_4588 buffer, int packedLight, int packedOverlay, int colour) {
		base.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		innerLeaf1.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		innerLeaf2.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		innerLeaf3.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		innerLeaf4.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		stem.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		mouthTop.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
		mouthBottom.method_22699(poseStack, buffer, packedLight, packedOverlay, colour);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 base = partdefinition.method_32117("base", class_5606.method_32108().method_32101(19, 9).method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-4.0F, -2.0F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F))
				.method_32101(40, 26).method_32098(-2.0F, -3.0F, -2.0F, 4.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 innerLeaf1 = partdefinition.method_32117("innerLeaf1", class_5606.method_32108().method_32101(31, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 38).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 23.0F, -4.0F));

		class_5610 cube_r1 = innerLeaf1.method_32117("cube_r1", class_5606.method_32108().method_32101(39, 16).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(45, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf2 = partdefinition.method_32117("innerLeaf2", class_5606.method_32108().method_32101(25, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(37, 0).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 23.0F, 4.0F, -3.1416F, 0.0F, 3.1416F));

		class_5610 cube_r2 = innerLeaf2.method_32117("cube_r2", class_5606.method_32108().method_32101(38, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(8, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf3 = partdefinition.method_32117("innerLeaf3", class_5606.method_32108().method_32101(19, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(26, 27).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 23.0F, 0.0F, 0.0F, 1.5708F, 0.0F));

		class_5610 cube_r3 = innerLeaf3.method_32117("cube_r3", class_5606.method_32108().method_32101(26, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(4, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf4 = partdefinition.method_32117("innerLeaf4", class_5606.method_32108().method_32101(13, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(12, 27).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 23.0F, 0.0F, 0.0F, -1.5708F, 0.0F));

		class_5610 cube_r4 = innerLeaf4.method_32117("cube_r4", class_5606.method_32108().method_32101(14, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(0, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 stem = partdefinition.method_32117("stem", class_5606.method_32108(), class_5603.method_32091(0.0F, 21.0F, 0.0F, -3.1416F, 0.0F, 3.1416F));

		class_5610 cube_r5 = stem.method_32117("cube_r5", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -15.2373F, 0.7932F, 2.0F, 6.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.1541F, -6.6976F, -0.7418F, 0.0F, 0.0F));

		class_5610 cube_r6 = stem.method_32117("cube_r6", class_5606.method_32108().method_32101(37, 48).method_32098(-1.0F, -9.2373F, 0.7932F, 2.0F, 6.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 0).method_32098(-1.5F, -3.2373F, 0.2932F, 3.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -8.198F, -4.1399F, -0.3927F, 0.0F, 0.0F));

		class_5610 cube_r7 = stem.method_32117("cube_r7", class_5606.method_32108().method_32101(0, 25).method_32098(-1.5F, -9.0F, -1.5F, 3.0F, 10.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 mouthTop = partdefinition.method_32117("mouthTop", class_5606.method_32108().method_32101(0, 17).method_32098(-3.0F, -1.0F, 1.0F, 6.0F, 1.0F, 7.0F, new class_5605(0.0F))
				.method_32101(9, 25).method_32098(-2.0F, -1.0F, 0.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(24, 6).method_32098(-2.0F, 0.0F, 0.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 7).method_32098(1.75F, 0.0F, 6.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 21).method_32098(3.0F, -1.0F, 6.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 20).method_32098(-4.0F, -1.0F, 6.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 19).method_32098(-3.75F, 0.0F, 5.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 17).method_32098(2.75F, 0.0F, 5.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 13).method_32098(3.75F, 0.0F, 3.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 11).method_32098(-4.75F, 0.0F, 3.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 0).method_32098(0.25F, 0.0F, 6.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 22).method_32098(-1.25F, 0.0F, 6.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 22).method_32098(-2.75F, 0.0F, 6.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(48, 32).method_32098(-5.0F, -1.0F, 2.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(46, 44).method_32098(3.0F, -1.0F, 2.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(22, 22).method_32098(-3.0F, -2.0F, 2.0F, 6.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.25F, -3.75F, -3.1416F, 0.0F, 3.1416F));

		class_5610 mouthBottom = partdefinition.method_32117("mouthBottom", class_5606.method_32108().method_32101(0, 9).method_32098(-3.0F, 0.0F, 0.0F, 6.0F, 1.0F, 7.0F, new class_5605(0.0F))
				.method_32101(19, 9).method_32098(1.75F, -1.0F, 5.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 19).method_32098(3.0F, 0.0F, 5.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 18).method_32098(-4.0F, 0.0F, 5.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 17).method_32098(-3.75F, -1.0F, 4.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 14).method_32098(2.75F, -1.0F, 4.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 13).method_32098(3.75F, -1.0F, 2.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 12).method_32098(-4.75F, -1.0F, 2.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 11).method_32098(0.25F, -1.0F, 5.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 10).method_32098(-1.25F, -1.0F, 5.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 9).method_32098(-2.75F, -1.0F, 5.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(43, 11).method_32098(-5.0F, 0.0F, 1.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(40, 31).method_32098(3.0F, 0.0F, 1.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(19, 17).method_32098(-3.0F, 1.0F, 1.0F, 6.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 1.25F, -4.75F, -3.1416F, 0.0F, 3.1416F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/SporetrapModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.minecraft.class_10042;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class SporetrapModel extends class_583<class_10042> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "sporetrap_model"), "main");
	private final class_630 base;
	private final class_630 innerLeaf1;
	private final class_630 innerLeaf2;
	private final class_630 innerLeaf3;
	private final class_630 innerLeaf4;
	private final class_630 stem;
	private final class_630 mouthTop;
	private final class_630 mouthBottom;

	public SporetrapModel(class_630 root) {
		super(root);
		this.base = root.method_32086("base");
		this.innerLeaf1 = root.method_32086("innerLeaf1");
		this.innerLeaf2 = root.method_32086("innerLeaf2");
		this.innerLeaf3 = root.method_32086("innerLeaf3");
		this.innerLeaf4 = root.method_32086("innerLeaf4");
		this.stem = root.method_32086("stem");
		this.mouthTop = root.method_32086("mouthTop");
		this.mouthBottom = root.method_32086("mouthBottom");
	}

	public void setupAnim(class_10042 state) {
		super.method_2819(state);
		float f1 = class_3532.method_15362(state.field_53450 * 1.4F) * 0.8F * state.field_53451;
		float f2 = class_3532.method_15362(state.field_53450 * 1.4F + class_3532.field_29844 * 0.25F) * 0.8F * state.field_53451;
		float f3 = class_3532.method_15362(state.field_53450 * 1.4F + class_3532.field_29844 * 0.5F) * 0.8F * state.field_53451;
		float f4 = class_3532.method_15362(state.field_53450 * 1.4F + class_3532.field_29844 * 0.75F) * 0.8F * state.field_53451;
		float f5 = class_3532.method_15362(state.field_53450 * 1.4F + class_3532.field_29844) * 0.8F * state.field_53451;
		this.mouthTop.field_3654 = -2.8F;
		this.mouthBottom.field_3654 = 2.8F;
		this.mouthTop.field_3654 += f1;
		this.mouthBottom.field_3654 += f5;
		this.innerLeaf1.field_3654 = 1F;
		this.innerLeaf2.field_3654 = 1F;
		this.innerLeaf3.field_3674 = 1F;
		this.innerLeaf4.field_3674 = 1F;
//		this.innerLeaf1.xRot += f1;
//		this.innerLeaf2.xRot += f1;
//		this.innerLeaf3.zRot += f1;
//		this.innerLeaf4.zRot += f1;
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 base = partdefinition.method_32117("base", class_5606.method_32108().method_32101(19, 9).method_32098(-3.0F, -1.0F, -3.0F, 6.0F, 1.0F, 6.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-4.0F, -2.0F, -4.0F, 8.0F, 1.0F, 8.0F, new class_5605(0.0F))
				.method_32101(40, 26).method_32098(-2.0F, -3.0F, -2.0F, 4.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 24.0F, 0.0F));

		class_5610 innerLeaf1 = partdefinition.method_32117("innerLeaf1", class_5606.method_32108().method_32101(31, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 38).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, 23.0F, -4.0F));

		class_5610 cube_r1 = innerLeaf1.method_32117("cube_r1", class_5606.method_32108().method_32101(39, 16).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(45, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf2 = partdefinition.method_32117("innerLeaf2", class_5606.method_32108().method_32101(25, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(37, 0).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 23.0F, 4.0F, -3.1416F, 0.0F, 3.1416F));

		class_5610 cube_r2 = innerLeaf2.method_32117("cube_r2", class_5606.method_32108().method_32101(38, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(8, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf3 = partdefinition.method_32117("innerLeaf3", class_5606.method_32108().method_32101(19, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(26, 27).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 23.0F, 0.0F, 0.0F, 1.5708F, 0.0F));

		class_5610 cube_r3 = innerLeaf3.method_32117("cube_r3", class_5606.method_32108().method_32101(26, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(4, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 innerLeaf4 = partdefinition.method_32117("innerLeaf4", class_5606.method_32108().method_32101(13, 48).method_32098(-1.0F, -10.0F, 0.0F, 2.0F, 11.0F, 1.0F, new class_5605(0.0F))
				.method_32101(12, 27).method_32098(-3.5F, -10.0F, 0.75F, 7.0F, 11.0F, 0.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 23.0F, 0.0F, 0.0F, -1.5708F, 0.0F));

		class_5610 cube_r4 = innerLeaf4.method_32117("cube_r4", class_5606.method_32108().method_32101(14, 38).method_32098(-3.0F, -10.0F, 0.75F, 6.0F, 10.0F, 0.0F, new class_5605(0.0F))
				.method_32101(0, 49).method_32098(-0.5F, -7.0F, 0.0F, 1.0F, 7.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -9.0F, 0.0F, -0.3491F, 0.0F, 0.0F));

		class_5610 stem = partdefinition.method_32117("stem", class_5606.method_32108(), class_5603.method_32091(0.0F, 21.0F, 0.0F, -3.1416F, 0.0F, 3.1416F));

		class_5610 cube_r5 = stem.method_32117("cube_r5", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -15.2373F, 0.7932F, 2.0F, 6.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.1541F, -6.6976F, -0.7418F, 0.0F, 0.0F));

		class_5610 cube_r6 = stem.method_32117("cube_r6", class_5606.method_32108().method_32101(37, 48).method_32098(-1.0F, -9.2373F, 0.7932F, 2.0F, 6.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 0).method_32098(-1.5F, -3.2373F, 0.2932F, 3.0F, 3.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -8.198F, -4.1399F, -0.3927F, 0.0F, 0.0F));

		class_5610 cube_r7 = stem.method_32117("cube_r7", class_5606.method_32108().method_32101(0, 25).method_32098(-1.5F, -9.0F, -1.5F, 3.0F, 10.0F, 3.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 mouthTop = partdefinition.method_32117("mouthTop", class_5606.method_32108().method_32101(0, 17).method_32098(-3.0F, -1.0F, 1.0F, 6.0F, 1.0F, 7.0F, new class_5605(0.0F))
				.method_32101(9, 25).method_32098(-2.0F, -1.0F, 0.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(24, 6).method_32098(-2.0F, 0.0F, 0.0F, 4.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 7).method_32098(1.75F, 0.0F, 6.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 21).method_32098(3.0F, -1.0F, 6.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 20).method_32098(-4.0F, -1.0F, 6.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 19).method_32098(-3.75F, 0.0F, 5.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 17).method_32098(2.75F, 0.0F, 5.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 13).method_32098(3.75F, 0.0F, 3.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 11).method_32098(-4.75F, 0.0F, 3.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(33, 0).method_32098(0.25F, 0.0F, 6.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 22).method_32098(-1.25F, 0.0F, 6.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 22).method_32098(-2.75F, 0.0F, 6.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(48, 32).method_32098(-5.0F, -1.0F, 2.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(46, 44).method_32098(3.0F, -1.0F, 2.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(22, 22).method_32098(-3.0F, -2.0F, 2.0F, 6.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.25F, -3.75F, -3.1416F, 0.0F, 3.1416F));

		class_5610 mouthBottom = partdefinition.method_32117("mouthBottom", class_5606.method_32108().method_32101(0, 9).method_32098(-3.0F, 0.0F, 0.0F, 6.0F, 1.0F, 7.0F, new class_5605(0.0F))
				.method_32101(19, 9).method_32098(1.75F, -1.0F, 5.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 19).method_32098(3.0F, 0.0F, 5.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 18).method_32098(-4.0F, 0.0F, 5.0F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 17).method_32098(-3.75F, -1.0F, 4.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 14).method_32098(2.75F, -1.0F, 4.25F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 13).method_32098(3.75F, -1.0F, 2.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 12).method_32098(-4.75F, -1.0F, 2.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 11).method_32098(0.25F, -1.0F, 5.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(3, 10).method_32098(-1.25F, -1.0F, 5.75F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 9).method_32098(-2.75F, -1.0F, 5.5F, 1.0F, 1.0F, 1.0F, new class_5605(0.0F))
				.method_32101(43, 11).method_32098(-5.0F, 0.0F, 1.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(40, 31).method_32098(3.0F, 0.0F, 1.0F, 2.0F, 1.0F, 4.0F, new class_5605(0.0F))
				.method_32101(19, 17).method_32098(-3.0F, 1.0F, 1.0F, 6.0F, 1.0F, 4.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 1.25F, -4.75F, -3.1416F, 0.0F, 3.1416F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}
